==> tentackle-model-11.2.3.0-sources.jar: org/tentackle/model/impl/ModelDirectory.java <==
/*
 * Tentackle - https://tentackle.org.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.tentackle.model.impl;

import java.util.List;
import org.tentackle.model.EntityAliases;
import org.tentackle.model.ModelDefaults;

/**
 * A directory holding model files.
 *
 * @author harald
 */
public interface ModelDirectory {

  /**
   * Gets the directory path.
   *
   * @return the path
   */
  String getPath();

  /**
   * Gets the model file names.
   *
   * @return the list of names, never null
   */
  List<String> getFileNames();

  /**
   * Gets the model defaults.
   *
   * @return the defaults, null if none
   */
  ModelDefaults getModelDefaults();

  /**
   * Gets the entity aliases.
   *
   * @return the aliases, null if none
   */
  EntityAliases getEntityAliases();

  /**
   * Returns whether the directory has changed.
   *
   * @return true if changed
   */
  boolean hasChanged();

  /**
   * Marks this directory dirty.
   */
  void markDirty();

}

==> tentackle-model-11.7.2.1-sources.jar: org/tentackle/model/impl/ModelDirectory.java <==
/*
 * Tentackle - https://tentackle.org.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.tentackle.model.impl;

import org.tentackle.model.EntityAliases;
import org.tentackle.model.ModelDefaults;

import java.util.List;

/**
 * A directory holding model files.
 *
 * @author harald
 */
public interface ModelDirectory {

  /**
   * Gets the directory path.
   *
   * @return the canonical path
   */
  String getPath();

  /**
   * Gets the model file paths.
   *
   * @return the list of canonical path names, never null
   */
  List<String> getFilePaths();

  /**
   * Gets the model defaults.
   *
   * @return the defaults, null if none
   */
  ModelDefaults getModelDefaults();

  /**
   * Gets the entity aliases.
   *
   * @return the aliases, null if none
   */
  EntityAliases getEntityAliases();

  /**
   * Returns whether the directory has changed.
   *
   * @return true if changed
   */
  boolean hasChanged();

  /**
   * Marks this directory dirty.
   */
  void markDirty();

}
